@@ -1,8 +1,10 @@
 import traceback
+import os
 from . import global_data
 from pathlib import Path
 import arrow
 import json
+import click
 import paho.mqtt.client as mqtt
 
 class PseudoClient(object):
@@ -28,6 +30,7 @@ class mqttwrapper(object):
             # in consecutive calls results starting from 1970
             'timestamp': str(arrow.get().to('utc')),
         }
+        self.output_to_console(value)
         self.client.publish(
             path,
             payload=json.dumps(value),
@@ -35,6 +38,15 @@ class mqttwrapper(object):
             retain=retain
         )
 
+    def output_to_console(self, value):
+        if os.getenv("SRE_OUTPUT_MESSAGES") != "1":
+            return
+        try:
+            value = json.dumps(value, indent=4)
+        except: pass
+
+        click.secho(str(value), fg='cyan')
+
 def _get_mqtt_wrapper(client, module):
     from . import global_data
     name = global_data['config'].config['name']
